# -*- coding: utf-8 -*-

import os, csv

from django.core.management.base import NoArgsCommand
from django.utils import encoding
from django.db import transaction

from jumbo.apps.abicab.models import *

M = {
    'abi':          0,
    'name':         1,
    'cab':          2,
    'agency':       3,
    'address':      4,
    'locality':     5,
    'zip_code':     6,
    'province':     7
}

class Command(NoArgsCommand):
    help = "Load Abi Cab from TabAbiCab.csv"

    def handle_noargs(self, **options):
        from django.conf import settings
        i = ImportRecords(
            "/jmb/bank/files/TabAbiCab.csv"
        )
        i.start_import()

class ImportRecords:
    def __init__(self, filename):
        self.filename = filename

    @transaction.commit_manually
    def start_import(self):
        fileReader = csv.reader(open(self.filename), delimiter='\t')

        for i, r in enumerate(fileReader):
            ## salto intestazione del file
            if i == 0:
                continue
            ## verifico che abi e cab siano valorizzati
            if not r[M['abi']] or not r[M['cab']]:
                print 'ATTENTION!!! ABI o CAB inesistente', i, r
                continue

            try:
                ## se esiste già non sovrascrivo
                b = Bank.objects.get(abi = r[M['abi']], cab = r[M['cab']])
            except:
                b = Bank()

            b.abi = r[M['abi']]
            b.cab = r[M['cab']]
            b.name = encoding.smart_unicode(r[M['name']], encoding='latin1')
            b.agency = encoding.smart_unicode(r[M['agency']], encoding='latin1')
            b.address = encoding.smart_unicode(r[M['address']], encoding='latin1')
            b.locality = encoding.smart_unicode(r[M['locality']], encoding='latin1')
            b.zip_code = r[M['zip_code']]
            b.province = r[M['province']]
            b.status = 1

            try:
                b.save()
                transaction.commit()
            except Exception, e:
                print 'ATTENTION!!! Errore inserimento', e, i
                transaction.rollback()
                continue
